"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class AggregationRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ROLE_SELECTORS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def cluster_role_selectors(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.LabelSelector]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        cluster_role_selectors: collections.abc.Iterable[kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.LabelSelector] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster_role_selectors", b"cluster_role_selectors", "resource_info", b"resource_info"]) -> None: ...

global___AggregationRule = AggregationRule

@typing_extensions.final
class ClusterRole(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AGGREGATION_RULE_FIELD_NUMBER: builtins.int
    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RULES_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def aggregation_rule(self) -> global___AggregationRule: ...
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PolicyRule]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        aggregation_rule: global___AggregationRule | None = ...,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        rules: collections.abc.Iterable[global___PolicyRule] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["aggregation_rule", b"aggregation_rule", "metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aggregation_rule", b"aggregation_rule", "api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "rules", b"rules"]) -> None: ...

global___ClusterRole = ClusterRole

@typing_extensions.final
class ClusterRoleBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    ROLE_REF_FIELD_NUMBER: builtins.int
    SUBJECTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def role_ref(self) -> global___RoleRef: ...
    @property
    def subjects(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Subject]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        role_ref: global___RoleRef | None = ...,
        subjects: collections.abc.Iterable[global___Subject] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "role_ref", b"role_ref"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "role_ref", b"role_ref", "subjects", b"subjects"]) -> None: ...

global___ClusterRoleBinding = ClusterRoleBinding

@typing_extensions.final
class ClusterRoleBindingList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ClusterRoleBinding]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___ClusterRoleBinding] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___ClusterRoleBindingList = ClusterRoleBindingList

@typing_extensions.final
class ClusterRoleList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ClusterRole]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___ClusterRole] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___ClusterRoleList = ClusterRoleList

@typing_extensions.final
class PolicyRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_GROUPS_FIELD_NUMBER: builtins.int
    NON_RESOURCE_U_R_LS_FIELD_NUMBER: builtins.int
    RESOURCE_NAMES_FIELD_NUMBER: builtins.int
    RESOURCES_FIELD_NUMBER: builtins.int
    VERBS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def api_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def non_resource_u_r_ls(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def resource_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def resources(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def verbs(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_groups: collections.abc.Iterable[builtins.str] | None = ...,
        non_resource_u_r_ls: collections.abc.Iterable[builtins.str] | None = ...,
        resource_names: collections.abc.Iterable[builtins.str] | None = ...,
        resources: collections.abc.Iterable[builtins.str] | None = ...,
        verbs: collections.abc.Iterable[builtins.str] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_groups", b"api_groups", "non_resource_u_r_ls", b"non_resource_u_r_ls", "resource_info", b"resource_info", "resource_names", b"resource_names", "resources", b"resources", "verbs", b"verbs"]) -> None: ...

global___PolicyRule = PolicyRule

@typing_extensions.final
class Role(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RULES_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PolicyRule]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        rules: collections.abc.Iterable[global___PolicyRule] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "rules", b"rules"]) -> None: ...

global___Role = Role

@typing_extensions.final
class RoleBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    ROLE_REF_FIELD_NUMBER: builtins.int
    SUBJECTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def role_ref(self) -> global___RoleRef: ...
    @property
    def subjects(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Subject]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        role_ref: global___RoleRef | None = ...,
        subjects: collections.abc.Iterable[global___Subject] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "role_ref", b"role_ref"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "role_ref", b"role_ref", "subjects", b"subjects"]) -> None: ...

global___RoleBinding = RoleBinding

@typing_extensions.final
class RoleBindingList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RoleBinding]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___RoleBinding] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___RoleBindingList = RoleBindingList

@typing_extensions.final
class RoleList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Role]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___Role] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___RoleList = RoleList

@typing_extensions.final
class RoleRef(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_GROUP_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_group: builtins.str
    kind: builtins.str
    name: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_group: builtins.str = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_group", b"api_group", "kind", b"kind", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___RoleRef = RoleRef

@typing_extensions.final
class Subject(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_GROUP_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NAMESPACE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_group: builtins.str
    kind: builtins.str
    name: builtins.str
    namespace: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_group: builtins.str = ...,
        kind: builtins.str = ...,
        name: builtins.str = ...,
        namespace: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_group", b"api_group", "kind", b"kind", "name", b"name", "namespace", b"namespace", "resource_info", b"resource_info"]) -> None: ...

global___Subject = Subject



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_opsworks.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16\x61ws/aws_opsworks.proto\x12\x18oak9.tython.aws.opsworks\x1a\x13shared/shared.proto\"\x98\x01\n\tAppSource\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x10\n\x08revision\x18\x03 \x01(\t\x12\x0f\n\x07ssh_key\x18\x04 \x01(\t\x12\x0b\n\x03url\x18\x05 \x01(\t\x12\x10\n\x08username\x18\x06 \x01(\t\"l\n\rAppDataSource\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03\x61rn\x18\x02 \x01(\t\x12\x15\n\rdatabase_name\x18\x03 \x01(\t\"}\n\x16\x41ppEnvironmentVariable\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\x0e\n\x06secure\x18\x03 \x01(\x08\x12\r\n\x05value\x18\x04 \x01(\t\"\x87\x01\n\x13\x41ppSslConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x63\x65rtificate\x18\x02 \x01(\t\x12\r\n\x05\x63hain\x18\x03 \x01(\t\x12\x13\n\x0bprivate_key\x18\x04 \x01(\t\"\xb8\x04\n\x03\x41pp\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x37\n\napp_source\x18\x02 \x01(\x0b\x32#.oak9.tython.aws.opsworks.AppSource\x12\x41\n\nattributes\x18\x03 \x03(\x0b\x32-.oak9.tython.aws.opsworks.App.AttributesEntry\x12=\n\x0c\x64\x61ta_sources\x18\x04 \x03(\x0b\x32\'.oak9.tython.aws.opsworks.AppDataSource\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x0f\n\x07\x64omains\x18\x06 \x03(\t\x12\x12\n\nenable_ssl\x18\x07 \x01(\x08\x12\x45\n\x0b\x65nvironment\x18\x08 \x03(\x0b\x32\x30.oak9.tython.aws.opsworks.AppEnvironmentVariable\x12\x0c\n\x04name\x18\t \x01(\t\x12\x11\n\tshortname\x18\n \x01(\t\x12H\n\x11ssl_configuration\x18\x0b \x01(\x0b\x32-.oak9.tython.aws.opsworks.AppSslConfiguration\x12\x10\n\x08stack_id\x18\x0c \x01(\t\x12\x0c\n\x04type\x18\r \x01(\t\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9e\x03\n\x08OpsWorks\x12*\n\x03\x61pp\x18\x01 \x03(\x0b\x32\x1d.oak9.tython.aws.opsworks.App\x12\x61\n elastic_load_balancer_attachment\x18\x02 \x03(\x0b\x32\x37.oak9.tython.aws.opsworks.ElasticLoadBalancerAttachment\x12\x34\n\x08instance\x18\x03 \x03(\x0b\x32\".oak9.tython.aws.opsworks.Instance\x12.\n\x05layer\x18\x04 \x03(\x0b\x32\x1f.oak9.tython.aws.opsworks.Layer\x12.\n\x05stack\x18\x05 \x03(\x0b\x32\x1f.oak9.tython.aws.opsworks.Stack\x12;\n\x0cuser_profile\x18\x06 \x03(\x0b\x32%.oak9.tython.aws.opsworks.UserProfile\x12\x30\n\x06volume\x18\x07 \x03(\x0b\x32 .oak9.tython.aws.opsworks.Volume\"\x8e\x01\n\x1d\x45lasticLoadBalancerAttachment\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\"\n\x1a\x65lastic_load_balancer_name\x18\x02 \x01(\t\x12\x10\n\x08layer_id\x18\x03 \x01(\t\"\xbd\x01\n\x16InstanceEbsBlockDevice\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1d\n\x15\x64\x65lete_on_termination\x18\x02 \x01(\x08\x12\x0c\n\x04iops\x18\x03 \x01(\x05\x12\x13\n\x0bsnapshot_id\x18\x04 \x01(\t\x12\x13\n\x0bvolume_size\x18\x05 \x01(\x05\x12\x13\n\x0bvolume_type\x18\x06 \x01(\t\"\xd2\x01\n\x1aInstanceBlockDeviceMapping\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65vice_name\x18\x02 \x01(\t\x12=\n\x03\x65\x62s\x18\x03 \x01(\x0b\x32\x30.oak9.tython.aws.opsworks.InstanceEbsBlockDevice\x12\x11\n\tno_device\x18\x04 \x01(\t\x12\x14\n\x0cvirtual_name\x18\x05 \x01(\t\"\x84\x08\n\x1cInstanceTimeBasedAutoScaling\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12R\n\x06\x66riday\x18\x02 \x03(\x0b\x32\x42.oak9.tython.aws.opsworks.InstanceTimeBasedAutoScaling.FridayEntry\x12R\n\x06monday\x18\x03 \x03(\x0b\x32\x42.oak9.tython.aws.opsworks.InstanceTimeBasedAutoScaling.MondayEntry\x12V\n\x08saturday\x18\x04 \x03(\x0b\x32\x44.oak9.tython.aws.opsworks.InstanceTimeBasedAutoScaling.SaturdayEntry\x12R\n\x06sunday\x18\x05 \x03(\x0b\x32\x42.oak9.tython.aws.opsworks.InstanceTimeBasedAutoScaling.SundayEntry\x12V\n\x08thursday\x18\x06 \x03(\x0b\x32\x44.oak9.tython.aws.opsworks.InstanceTimeBasedAutoScaling.ThursdayEntry\x12T\n\x07tuesday\x18\x07 \x03(\x0b\x32\x43.oak9.tython.aws.opsworks.InstanceTimeBasedAutoScaling.TuesdayEntry\x12X\n\twednesday\x18\x08 \x03(\x0b\x32\x45.oak9.tython.aws.opsworks.InstanceTimeBasedAutoScaling.WednesdayEntry\x1a-\n\x0b\x46ridayEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a-\n\x0bMondayEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\rSaturdayEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a-\n\x0bSundayEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\rThursdayEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a.\n\x0cTuesdayEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x30\n\x0eWednesdayEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8d\x05\n\x08Instance\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\ragent_version\x18\x02 \x01(\t\x12\x0e\n\x06\x61mi_id\x18\x03 \x01(\t\x12\x14\n\x0c\x61rchitecture\x18\x04 \x01(\t\x12\x19\n\x11\x61uto_scaling_type\x18\x05 \x01(\t\x12\x19\n\x11\x61vailability_zone\x18\x06 \x01(\t\x12S\n\x15\x62lock_device_mappings\x18\x07 \x03(\x0b\x32\x34.oak9.tython.aws.opsworks.InstanceBlockDeviceMapping\x12\x15\n\rebs_optimized\x18\x08 \x01(\x08\x12\x13\n\x0b\x65lastic_ips\x18\t \x03(\t\x12\x10\n\x08hostname\x18\n \x01(\t\x12\x1f\n\x17install_updates_on_boot\x18\x0b \x01(\x08\x12\x15\n\rinstance_type\x18\x0c \x01(\t\x12\x11\n\tlayer_ids\x18\r \x03(\t\x12\n\n\x02os\x18\x0e \x01(\t\x12\x18\n\x10root_device_type\x18\x0f \x01(\t\x12\x14\n\x0cssh_key_name\x18\x10 \x01(\t\x12\x10\n\x08stack_id\x18\x11 \x01(\t\x12\x11\n\tsubnet_id\x18\x12 \x01(\t\x12\x0f\n\x07tenancy\x18\x13 \x01(\t\x12W\n\x17time_based_auto_scaling\x18\x14 \x01(\x0b\x32\x36.oak9.tython.aws.opsworks.InstanceTimeBasedAutoScaling\x12\x1b\n\x13virtualization_type\x18\x15 \x01(\t\x12\x0f\n\x07volumes\x18\x16 \x03(\t\"\x9d\x01\n\x0cLayerRecipes\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tconfigure\x18\x02 \x03(\t\x12\x0e\n\x06\x64\x65ploy\x18\x03 \x03(\t\x12\r\n\x05setup\x18\x04 \x03(\t\x12\x10\n\x08shutdown\x18\x05 \x03(\t\x12\x10\n\x08undeploy\x18\x06 \x03(\t\"\xa2\x01\n\x1fLayerShutdownEventConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12+\n#delay_until_elb_connections_drained\x18\x02 \x01(\x08\x12\x19\n\x11\x65xecution_timeout\x18\x03 \x01(\x05\"\xbc\x01\n LayerLifecycleEventConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12_\n\x1cshutdown_event_configuration\x18\x02 \x01(\x0b\x32\x39.oak9.tython.aws.opsworks.LayerShutdownEventConfiguration\"\xf1\x01\n\x1aLayerAutoScalingThresholds\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rcpu_threshold\x18\x02 \x01(\x01\x12\x1b\n\x13ignore_metrics_time\x18\x03 \x01(\x05\x12\x16\n\x0einstance_count\x18\x04 \x01(\x05\x12\x16\n\x0eload_threshold\x18\x05 \x01(\x01\x12\x18\n\x10memory_threshold\x18\x06 \x01(\x01\x12\x1c\n\x14thresholds_wait_time\x18\x07 \x01(\x05\"\xfa\x01\n\x19LayerLoadBasedAutoScaling\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12J\n\x0c\x64own_scaling\x18\x02 \x01(\x0b\x32\x34.oak9.tython.aws.opsworks.LayerAutoScalingThresholds\x12\x0e\n\x06\x65nable\x18\x03 \x01(\x08\x12H\n\nup_scaling\x18\x04 \x01(\x0b\x32\x34.oak9.tython.aws.opsworks.LayerAutoScalingThresholds\"\xd9\x01\n\x18LayerVolumeConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tencrypted\x18\x02 \x01(\x08\x12\x0c\n\x04iops\x18\x03 \x01(\x05\x12\x13\n\x0bmount_point\x18\x04 \x01(\t\x12\x17\n\x0fnumber_of_disks\x18\x05 \x01(\x05\x12\x12\n\nraid_level\x18\x06 \x01(\x05\x12\x0c\n\x04size\x18\x07 \x01(\x05\x12\x13\n\x0bvolume_type\x18\x08 \x01(\t\"\xa2\x08\n\x05Layer\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x43\n\nattributes\x18\x02 \x03(\x0b\x32/.oak9.tython.aws.opsworks.Layer.AttributesEntry\x12\x1f\n\x17\x61uto_assign_elastic_ips\x18\x03 \x01(\x08\x12\x1e\n\x16\x61uto_assign_public_ips\x18\x04 \x01(\x08\x12#\n\x1b\x63ustom_instance_profile_arn\x18\x05 \x01(\t\x12\x44\n\x0b\x63ustom_json\x18\x06 \x03(\x0b\x32/.oak9.tython.aws.opsworks.Layer.CustomJsonEntry\x12>\n\x0e\x63ustom_recipes\x18\x07 \x01(\x0b\x32&.oak9.tython.aws.opsworks.LayerRecipes\x12!\n\x19\x63ustom_security_group_ids\x18\x08 \x03(\t\x12\x1b\n\x13\x65nable_auto_healing\x18\t \x01(\x08\x12\x1f\n\x17install_updates_on_boot\x18\n \x01(\x08\x12\x61\n\x1dlifecycle_event_configuration\x18\x0b \x01(\x0b\x32:.oak9.tython.aws.opsworks.LayerLifecycleEventConfiguration\x12T\n\x17load_based_auto_scaling\x18\x0c \x01(\x0b\x32\x33.oak9.tython.aws.opsworks.LayerLoadBasedAutoScaling\x12\x0c\n\x04name\x18\r \x01(\t\x12\x10\n\x08packages\x18\x0e \x03(\t\x12\x11\n\tshortname\x18\x0f \x01(\t\x12\x10\n\x08stack_id\x18\x10 \x01(\t\x12\x37\n\x04tags\x18\x11 \x03(\x0b\x32).oak9.tython.aws.opsworks.Layer.TagsEntry\x12\x0c\n\x04type\x18\x12 \x01(\t\x12#\n\x1buse_ebs_optimized_instances\x18\x13 \x01(\x08\x12Q\n\x15volume_configurations\x18\x14 \x03(\x0b\x32\x32.oak9.tython.aws.opsworks.LayerVolumeConfiguration\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x31\n\x0f\x43ustomJsonEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x86\x01\n\x16StackChefConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11\x62\x65rkshelf_version\x18\x02 \x01(\t\x12\x18\n\x10manage_berkshelf\x18\x03 \x01(\x08\"x\n\x1eStackStackConfigurationManager\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\"\x9a\x01\n\x0bStackSource\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x10\n\x08revision\x18\x03 \x01(\t\x12\x0f\n\x07ssh_key\x18\x04 \x01(\t\x12\x0b\n\x03url\x18\x05 \x01(\t\x12\x10\n\x08username\x18\x06 \x01(\t\"c\n\x0eStackElasticIp\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\n\n\x02ip\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"\x90\x01\n\x12StackRdsDbInstance\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x62_password\x18\x02 \x01(\t\x12\x0f\n\x07\x64\x62_user\x18\x03 \x01(\t\x12\x1b\n\x13rds_db_instance_arn\x18\x04 \x01(\t\"\xd4\t\n\x05Stack\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\ragent_version\x18\x02 \x01(\t\x12\x43\n\nattributes\x18\x03 \x03(\x0b\x32/.oak9.tython.aws.opsworks.Stack.AttributesEntry\x12L\n\x12\x63hef_configuration\x18\x04 \x01(\x0b\x32\x30.oak9.tython.aws.opsworks.StackChefConfiguration\x12\x15\n\rclone_app_ids\x18\x05 \x03(\t\x12\x19\n\x11\x63lone_permissions\x18\x06 \x01(\x08\x12W\n\x15\x63onfiguration_manager\x18\x07 \x01(\x0b\x32\x38.oak9.tython.aws.opsworks.StackStackConfigurationManager\x12\x46\n\x17\x63ustom_cookbooks_source\x18\x08 \x01(\x0b\x32%.oak9.tython.aws.opsworks.StackSource\x12\x44\n\x0b\x63ustom_json\x18\t \x03(\x0b\x32/.oak9.tython.aws.opsworks.Stack.CustomJsonEntry\x12!\n\x19\x64\x65\x66\x61ult_availability_zone\x18\n \x01(\t\x12$\n\x1c\x64\x65\x66\x61ult_instance_profile_arn\x18\x0b \x01(\t\x12\x12\n\ndefault_os\x18\x0c \x01(\t\x12 \n\x18\x64\x65\x66\x61ult_root_device_type\x18\r \x01(\t\x12\x1c\n\x14\x64\x65\x66\x61ult_ssh_key_name\x18\x0e \x01(\t\x12\x19\n\x11\x64\x65\x66\x61ult_subnet_id\x18\x0f \x01(\t\x12\x17\n\x0f\x65\x63s_cluster_arn\x18\x10 \x01(\t\x12=\n\x0b\x65lastic_ips\x18\x11 \x03(\x0b\x32(.oak9.tython.aws.opsworks.StackElasticIp\x12\x16\n\x0ehostname_theme\x18\x12 \x01(\t\x12\x0c\n\x04name\x18\x13 \x01(\t\x12\x46\n\x10rds_db_instances\x18\x14 \x03(\x0b\x32,.oak9.tython.aws.opsworks.StackRdsDbInstance\x12\x18\n\x10service_role_arn\x18\x15 \x01(\t\x12\x17\n\x0fsource_stack_id\x18\x16 \x01(\t\x12\x37\n\x04tags\x18\x17 \x03(\x0b\x32).oak9.tython.aws.opsworks.Stack.TagsEntry\x12\x1c\n\x14use_custom_cookbooks\x18\x18 \x01(\x08\x12$\n\x1cuse_opsworks_security_groups\x18\x19 \x01(\x08\x12\x0e\n\x06vpc_id\x18\x1a \x01(\t\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x31\n\x0f\x43ustomJsonEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa9\x01\n\x0bUserProfile\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1d\n\x15\x61llow_self_management\x18\x02 \x01(\x08\x12\x14\n\x0ciam_user_arn\x18\x03 \x01(\t\x12\x16\n\x0essh_public_key\x18\x04 \x01(\t\x12\x14\n\x0cssh_username\x18\x05 \x01(\t\"\x8d\x01\n\x06Volume\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rec2_volume_id\x18\x02 \x01(\t\x12\x13\n\x0bmount_point\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x10\n\x08stack_id\x18\x05 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_opsworks_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _APP_ATTRIBUTESENTRY._options = None
  _APP_ATTRIBUTESENTRY._serialized_options = b'8\001'
  _INSTANCETIMEBASEDAUTOSCALING_FRIDAYENTRY._options = None
  _INSTANCETIMEBASEDAUTOSCALING_FRIDAYENTRY._serialized_options = b'8\001'
  _INSTANCETIMEBASEDAUTOSCALING_MONDAYENTRY._options = None
  _INSTANCETIMEBASEDAUTOSCALING_MONDAYENTRY._serialized_options = b'8\001'
  _INSTANCETIMEBASEDAUTOSCALING_SATURDAYENTRY._options = None
  _INSTANCETIMEBASEDAUTOSCALING_SATURDAYENTRY._serialized_options = b'8\001'
  _INSTANCETIMEBASEDAUTOSCALING_SUNDAYENTRY._options = None
  _INSTANCETIMEBASEDAUTOSCALING_SUNDAYENTRY._serialized_options = b'8\001'
  _INSTANCETIMEBASEDAUTOSCALING_THURSDAYENTRY._options = None
  _INSTANCETIMEBASEDAUTOSCALING_THURSDAYENTRY._serialized_options = b'8\001'
  _INSTANCETIMEBASEDAUTOSCALING_TUESDAYENTRY._options = None
  _INSTANCETIMEBASEDAUTOSCALING_TUESDAYENTRY._serialized_options = b'8\001'
  _INSTANCETIMEBASEDAUTOSCALING_WEDNESDAYENTRY._options = None
  _INSTANCETIMEBASEDAUTOSCALING_WEDNESDAYENTRY._serialized_options = b'8\001'
  _LAYER_ATTRIBUTESENTRY._options = None
  _LAYER_ATTRIBUTESENTRY._serialized_options = b'8\001'
  _LAYER_CUSTOMJSONENTRY._options = None
  _LAYER_CUSTOMJSONENTRY._serialized_options = b'8\001'
  _LAYER_TAGSENTRY._options = None
  _LAYER_TAGSENTRY._serialized_options = b'8\001'
  _STACK_ATTRIBUTESENTRY._options = None
  _STACK_ATTRIBUTESENTRY._serialized_options = b'8\001'
  _STACK_CUSTOMJSONENTRY._options = None
  _STACK_CUSTOMJSONENTRY._serialized_options = b'8\001'
  _STACK_TAGSENTRY._options = None
  _STACK_TAGSENTRY._serialized_options = b'8\001'
  _APPSOURCE._serialized_start=74
  _APPSOURCE._serialized_end=226
  _APPDATASOURCE._serialized_start=228
  _APPDATASOURCE._serialized_end=336
  _APPENVIRONMENTVARIABLE._serialized_start=338
  _APPENVIRONMENTVARIABLE._serialized_end=463
  _APPSSLCONFIGURATION._serialized_start=466
  _APPSSLCONFIGURATION._serialized_end=601
  _APP._serialized_start=604
  _APP._serialized_end=1172
  _APP_ATTRIBUTESENTRY._serialized_start=1123
  _APP_ATTRIBUTESENTRY._serialized_end=1172
  _OPSWORKS._serialized_start=1175
  _OPSWORKS._serialized_end=1589
  _ELASTICLOADBALANCERATTACHMENT._serialized_start=1592
  _ELASTICLOADBALANCERATTACHMENT._serialized_end=1734
  _INSTANCEEBSBLOCKDEVICE._serialized_start=1737
  _INSTANCEEBSBLOCKDEVICE._serialized_end=1926
  _INSTANCEBLOCKDEVICEMAPPING._serialized_start=1929
  _INSTANCEBLOCKDEVICEMAPPING._serialized_end=2139
  _INSTANCETIMEBASEDAUTOSCALING._serialized_start=2142
  _INSTANCETIMEBASEDAUTOSCALING._serialized_end=3170
  _INSTANCETIMEBASEDAUTOSCALING_FRIDAYENTRY._serialized_start=2835
  _INSTANCETIMEBASEDAUTOSCALING_FRIDAYENTRY._serialized_end=2880
  _INSTANCETIMEBASEDAUTOSCALING_MONDAYENTRY._serialized_start=2882
  _INSTANCETIMEBASEDAUTOSCALING_MONDAYENTRY._serialized_end=2927
  _INSTANCETIMEBASEDAUTOSCALING_SATURDAYENTRY._serialized_start=2929
  _INSTANCETIMEBASEDAUTOSCALING_SATURDAYENTRY._serialized_end=2976
  _INSTANCETIMEBASEDAUTOSCALING_SUNDAYENTRY._serialized_start=2978
  _INSTANCETIMEBASEDAUTOSCALING_SUNDAYENTRY._serialized_end=3023
  _INSTANCETIMEBASEDAUTOSCALING_THURSDAYENTRY._serialized_start=3025
  _INSTANCETIMEBASEDAUTOSCALING_THURSDAYENTRY._serialized_end=3072
  _INSTANCETIMEBASEDAUTOSCALING_TUESDAYENTRY._serialized_start=3074
  _INSTANCETIMEBASEDAUTOSCALING_TUESDAYENTRY._serialized_end=3120
  _INSTANCETIMEBASEDAUTOSCALING_WEDNESDAYENTRY._serialized_start=3122
  _INSTANCETIMEBASEDAUTOSCALING_WEDNESDAYENTRY._serialized_end=3170
  _INSTANCE._serialized_start=3173
  _INSTANCE._serialized_end=3826
  _LAYERRECIPES._serialized_start=3829
  _LAYERRECIPES._serialized_end=3986
  _LAYERSHUTDOWNEVENTCONFIGURATION._serialized_start=3989
  _LAYERSHUTDOWNEVENTCONFIGURATION._serialized_end=4151
  _LAYERLIFECYCLEEVENTCONFIGURATION._serialized_start=4154
  _LAYERLIFECYCLEEVENTCONFIGURATION._serialized_end=4342
  _LAYERAUTOSCALINGTHRESHOLDS._serialized_start=4345
  _LAYERAUTOSCALINGTHRESHOLDS._serialized_end=4586
  _LAYERLOADBASEDAUTOSCALING._serialized_start=4589
  _LAYERLOADBASEDAUTOSCALING._serialized_end=4839
  _LAYERVOLUMECONFIGURATION._serialized_start=4842
  _LAYERVOLUMECONFIGURATION._serialized_end=5059
  _LAYER._serialized_start=5062
  _LAYER._serialized_end=6120
  _LAYER_ATTRIBUTESENTRY._serialized_start=1123
  _LAYER_ATTRIBUTESENTRY._serialized_end=1172
  _LAYER_CUSTOMJSONENTRY._serialized_start=6026
  _LAYER_CUSTOMJSONENTRY._serialized_end=6075
  _LAYER_TAGSENTRY._serialized_start=6077
  _LAYER_TAGSENTRY._serialized_end=6120
  _STACKCHEFCONFIGURATION._serialized_start=6123
  _STACKCHEFCONFIGURATION._serialized_end=6257
  _STACKSTACKCONFIGURATIONMANAGER._serialized_start=6259
  _STACKSTACKCONFIGURATIONMANAGER._serialized_end=6379
  _STACKSOURCE._serialized_start=6382
  _STACKSOURCE._serialized_end=6536
  _STACKELASTICIP._serialized_start=6538
  _STACKELASTICIP._serialized_end=6637
  _STACKRDSDBINSTANCE._serialized_start=6640
  _STACKRDSDBINSTANCE._serialized_end=6784
  _STACK._serialized_start=6787
  _STACK._serialized_end=8023
  _STACK_ATTRIBUTESENTRY._serialized_start=1123
  _STACK_ATTRIBUTESENTRY._serialized_end=1172
  _STACK_CUSTOMJSONENTRY._serialized_start=6026
  _STACK_CUSTOMJSONENTRY._serialized_end=6075
  _STACK_TAGSENTRY._serialized_start=6077
  _STACK_TAGSENTRY._serialized_end=6120
  _USERPROFILE._serialized_start=8026
  _USERPROFILE._serialized_end=8195
  _VOLUME._serialized_start=8198
  _VOLUME._serialized_end=8339
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Microsoft_EventGrid(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DOMAINS_FIELD_NUMBER: builtins.int
    DOMAINS_PRIVATE_ENDPOINT_CONNECTIONS_FIELD_NUMBER: builtins.int
    DOMAINS_TOPICS_FIELD_NUMBER: builtins.int
    TOPICS_FIELD_NUMBER: builtins.int
    TOPICS_PRIVATE_ENDPOINT_CONNECTIONS_FIELD_NUMBER: builtins.int
    @property
    def domains(self) -> global___Domains: ...
    @property
    def domains_private_endpoint_connections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DomainsPrivateEndpointConnections]: ...
    @property
    def domains_topics(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DomainsTopics]: ...
    @property
    def topics(self) -> global___Topics: ...
    @property
    def topics_private_endpoint_connections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TopicsPrivateEndpointConnections]: ...
    def __init__(
        self,
        *,
        domains: global___Domains | None = ...,
        domains_private_endpoint_connections: collections.abc.Iterable[global___DomainsPrivateEndpointConnections] | None = ...,
        domains_topics: collections.abc.Iterable[global___DomainsTopics] | None = ...,
        topics: global___Topics | None = ...,
        topics_private_endpoint_connections: collections.abc.Iterable[global___TopicsPrivateEndpointConnections] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["domains", b"domains", "topics", b"topics"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["domains", b"domains", "domains_private_endpoint_connections", b"domains_private_endpoint_connections", "domains_topics", b"domains_topics", "topics", b"topics", "topics_private_endpoint_connections", b"topics_private_endpoint_connections"]) -> None: ...

global___Microsoft_EventGrid = Microsoft_EventGrid

@typing_extensions.final
class TopicsPrivateEndpointConnections(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    GROUP_IDS_FIELD_NUMBER: builtins.int
    PRIVATE_ENDPOINT_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_SERVICE_CONNECTION_STATE_FIELD_NUMBER: builtins.int
    PROVISIONING_STATE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def private_endpoint(self) -> global___PrivateEndpoint: ...
    @property
    def private_link_service_connection_state(self) -> global___ConnectionState: ...
    provisioning_state: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        private_endpoint: global___PrivateEndpoint | None = ...,
        private_link_service_connection_state: global___ConnectionState | None = ...,
        provisioning_state: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["group_ids", b"group_ids", "name", b"name", "private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "provisioning_state", b"provisioning_state", "resource_info", b"resource_info"]) -> None: ...

global___TopicsPrivateEndpointConnections = TopicsPrivateEndpointConnections

@typing_extensions.final
class Topics(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DISABLE_LOCAL_AUTH_FIELD_NUMBER: builtins.int
    INBOUND_IP_RULES_FIELD_NUMBER: builtins.int
    INPUT_SCHEMA_FIELD_NUMBER: builtins.int
    INPUT_SCHEMA_MAPPING_FIELD_NUMBER: builtins.int
    PUBLIC_NETWORK_ACCESS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___IdentityInfo: ...
    location: builtins.str
    name: builtins.str
    disable_local_auth: builtins.bool
    @property
    def inbound_ip_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___InboundIpRule]: ...
    input_schema: builtins.str
    @property
    def input_schema_mapping(self) -> global___InputSchemaMapping: ...
    public_network_access: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___IdentityInfo | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        disable_local_auth: builtins.bool = ...,
        inbound_ip_rules: collections.abc.Iterable[global___InboundIpRule] | None = ...,
        input_schema: builtins.str = ...,
        input_schema_mapping: global___InputSchemaMapping | None = ...,
        public_network_access: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identity", b"identity", "input_schema_mapping", b"input_schema_mapping", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["disable_local_auth", b"disable_local_auth", "identity", b"identity", "inbound_ip_rules", b"inbound_ip_rules", "input_schema", b"input_schema", "input_schema_mapping", b"input_schema_mapping", "location", b"location", "name", b"name", "public_network_access", b"public_network_access", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___Topics = Topics

@typing_extensions.final
class SystemTopicsEventSubscriptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DEAD_LETTER_DESTINATION_FIELD_NUMBER: builtins.int
    DEAD_LETTER_WITH_RESOURCE_IDENTITY_FIELD_NUMBER: builtins.int
    DELIVERY_WITH_RESOURCE_IDENTITY_FIELD_NUMBER: builtins.int
    DESTINATION_FIELD_NUMBER: builtins.int
    EVENT_DELIVERY_SCHEMA_FIELD_NUMBER: builtins.int
    EXPIRATION_TIME_UTC_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    RETRY_POLICY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def dead_letter_destination(self) -> global___DeadLetterDestination: ...
    @property
    def dead_letter_with_resource_identity(self) -> global___DeadLetterWithResourceIdentity: ...
    @property
    def delivery_with_resource_identity(self) -> global___DeliveryWithResourceIdentity: ...
    @property
    def destination(self) -> global___EventSubscriptionDestination: ...
    event_delivery_schema: builtins.str
    expiration_time_utc: builtins.str
    @property
    def filter(self) -> global___EventSubscriptionFilter: ...
    @property
    def labels(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def retry_policy(self) -> global___RetryPolicy: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        dead_letter_destination: global___DeadLetterDestination | None = ...,
        dead_letter_with_resource_identity: global___DeadLetterWithResourceIdentity | None = ...,
        delivery_with_resource_identity: global___DeliveryWithResourceIdentity | None = ...,
        destination: global___EventSubscriptionDestination | None = ...,
        event_delivery_schema: builtins.str = ...,
        expiration_time_utc: builtins.str = ...,
        filter: global___EventSubscriptionFilter | None = ...,
        labels: collections.abc.Iterable[builtins.str] | None = ...,
        retry_policy: global___RetryPolicy | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dead_letter_destination", b"dead_letter_destination", "dead_letter_with_resource_identity", b"dead_letter_with_resource_identity", "delivery_with_resource_identity", b"delivery_with_resource_identity", "destination", b"destination", "filter", b"filter", "resource_info", b"resource_info", "retry_policy", b"retry_policy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dead_letter_destination", b"dead_letter_destination", "dead_letter_with_resource_identity", b"dead_letter_with_resource_identity", "delivery_with_resource_identity", b"delivery_with_resource_identity", "destination", b"destination", "event_delivery_schema", b"event_delivery_schema", "expiration_time_utc", b"expiration_time_utc", "filter", b"filter", "labels", b"labels", "name", b"name", "resource_info", b"resource_info", "retry_policy", b"retry_policy"]) -> None: ...

global___SystemTopicsEventSubscriptions = SystemTopicsEventSubscriptions

@typing_extensions.final
class RetryPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EVENT_TIME_TO_LIVE_IN_MINUTES_FIELD_NUMBER: builtins.int
    MAX_DELIVERY_ATTEMPTS_FIELD_NUMBER: builtins.int
    event_time_to_live_in_minutes: builtins.int
    max_delivery_attempts: builtins.int
    def __init__(
        self,
        *,
        event_time_to_live_in_minutes: builtins.int = ...,
        max_delivery_attempts: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["event_time_to_live_in_minutes", b"event_time_to_live_in_minutes", "max_delivery_attempts", b"max_delivery_attempts"]) -> None: ...

global___RetryPolicy = RetryPolicy

@typing_extensions.final
class EventSubscriptionFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADVANCED_FILTERS_FIELD_NUMBER: builtins.int
    ENABLE_ADVANCED_FILTERING_ON_ARRAYS_FIELD_NUMBER: builtins.int
    INCLUDED_EVENT_TYPES_FIELD_NUMBER: builtins.int
    IS_SUBJECT_CASE_SENSITIVE_FIELD_NUMBER: builtins.int
    SUBJECT_BEGINS_WITH_FIELD_NUMBER: builtins.int
    SUBJECT_ENDS_WITH_FIELD_NUMBER: builtins.int
    @property
    def advanced_filters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AdvancedFilter]: ...
    enable_advanced_filtering_on_arrays: builtins.bool
    @property
    def included_event_types(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    is_subject_case_sensitive: builtins.bool
    subject_begins_with: builtins.str
    subject_ends_with: builtins.str
    def __init__(
        self,
        *,
        advanced_filters: collections.abc.Iterable[global___AdvancedFilter] | None = ...,
        enable_advanced_filtering_on_arrays: builtins.bool = ...,
        included_event_types: collections.abc.Iterable[builtins.str] | None = ...,
        is_subject_case_sensitive: builtins.bool = ...,
        subject_begins_with: builtins.str = ...,
        subject_ends_with: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["advanced_filters", b"advanced_filters", "enable_advanced_filtering_on_arrays", b"enable_advanced_filtering_on_arrays", "included_event_types", b"included_event_types", "is_subject_case_sensitive", b"is_subject_case_sensitive", "subject_begins_with", b"subject_begins_with", "subject_ends_with", b"subject_ends_with"]) -> None: ...

global___EventSubscriptionFilter = EventSubscriptionFilter

@typing_extensions.final
class AdvancedFilter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_FIELD_NUMBER: builtins.int
    key: builtins.str
    def __init__(
        self,
        *,
        key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key"]) -> None: ...

global___AdvancedFilter = AdvancedFilter

@typing_extensions.final
class DeliveryWithResourceIdentity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESTINATION_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    @property
    def destination(self) -> global___EventSubscriptionDestination: ...
    @property
    def identity(self) -> global___EventSubscriptionIdentity: ...
    def __init__(
        self,
        *,
        destination: global___EventSubscriptionDestination | None = ...,
        identity: global___EventSubscriptionIdentity | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["destination", b"destination", "identity", b"identity"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["destination", b"destination", "identity", b"identity"]) -> None: ...

global___DeliveryWithResourceIdentity = DeliveryWithResourceIdentity

@typing_extensions.final
class EventSubscriptionDestination(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___EventSubscriptionDestination = EventSubscriptionDestination

@typing_extensions.final
class DeadLetterWithResourceIdentity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEAD_LETTER_DESTINATION_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    @property
    def dead_letter_destination(self) -> global___DeadLetterDestination: ...
    @property
    def identity(self) -> global___EventSubscriptionIdentity: ...
    def __init__(
        self,
        *,
        dead_letter_destination: global___DeadLetterDestination | None = ...,
        identity: global___EventSubscriptionIdentity | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dead_letter_destination", b"dead_letter_destination", "identity", b"identity"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dead_letter_destination", b"dead_letter_destination", "identity", b"identity"]) -> None: ...

global___DeadLetterWithResourceIdentity = DeadLetterWithResourceIdentity

@typing_extensions.final
class EventSubscriptionIdentity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    USER_ASSIGNED_IDENTITY_FIELD_NUMBER: builtins.int
    type: builtins.str
    user_assigned_identity: builtins.str
    def __init__(
        self,
        *,
        type: builtins.str = ...,
        user_assigned_identity: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["type", b"type", "user_assigned_identity", b"user_assigned_identity"]) -> None: ...

global___EventSubscriptionIdentity = EventSubscriptionIdentity

@typing_extensions.final
class DeadLetterDestination(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___DeadLetterDestination = DeadLetterDestination

@typing_extensions.final
class SystemTopics(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    TOPIC_TYPE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    SYSTEM_TOPICS_EVENT_SUBSCRIPTIONS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___IdentityInfo: ...
    location: builtins.str
    name: builtins.str
    source: builtins.str
    topic_type: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def system_topics_event_subscriptions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SystemTopicsEventSubscriptions]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___IdentityInfo | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        source: builtins.str = ...,
        topic_type: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        system_topics_event_subscriptions: collections.abc.Iterable[global___SystemTopicsEventSubscriptions] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identity", b"identity", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["identity", b"identity", "location", b"location", "name", b"name", "resource_info", b"resource_info", "source", b"source", "system_topics_event_subscriptions", b"system_topics_event_subscriptions", "tags", b"tags", "topic_type", b"topic_type"]) -> None: ...

global___SystemTopics = SystemTopics

@typing_extensions.final
class DomainsTopics(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___DomainsTopics = DomainsTopics

@typing_extensions.final
class DomainsPrivateEndpointConnections(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    GROUP_IDS_FIELD_NUMBER: builtins.int
    PRIVATE_ENDPOINT_FIELD_NUMBER: builtins.int
    PRIVATE_LINK_SERVICE_CONNECTION_STATE_FIELD_NUMBER: builtins.int
    PROVISIONING_STATE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    @property
    def group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def private_endpoint(self) -> global___PrivateEndpoint: ...
    @property
    def private_link_service_connection_state(self) -> global___ConnectionState: ...
    provisioning_state: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        private_endpoint: global___PrivateEndpoint | None = ...,
        private_link_service_connection_state: global___ConnectionState | None = ...,
        provisioning_state: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["group_ids", b"group_ids", "name", b"name", "private_endpoint", b"private_endpoint", "private_link_service_connection_state", b"private_link_service_connection_state", "provisioning_state", b"provisioning_state", "resource_info", b"resource_info"]) -> None: ...

global___DomainsPrivateEndpointConnections = DomainsPrivateEndpointConnections

@typing_extensions.final
class ConnectionState(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTIONS_REQUIRED_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    actions_required: builtins.str
    description: builtins.str
    status: builtins.str
    def __init__(
        self,
        *,
        actions_required: builtins.str = ...,
        description: builtins.str = ...,
        status: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["actions_required", b"actions_required", "description", b"description", "status", b"status"]) -> None: ...

global___ConnectionState = ConnectionState

@typing_extensions.final
class PrivateEndpoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id"]) -> None: ...

global___PrivateEndpoint = PrivateEndpoint

@typing_extensions.final
class Domains(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AUTO_CREATE_TOPIC_WITH_FIRST_SUBSCRIPTION_FIELD_NUMBER: builtins.int
    AUTO_DELETE_TOPIC_WITH_LAST_SUBSCRIPTION_FIELD_NUMBER: builtins.int
    DISABLE_LOCAL_AUTH_FIELD_NUMBER: builtins.int
    INBOUND_IP_RULES_FIELD_NUMBER: builtins.int
    INPUT_SCHEMA_FIELD_NUMBER: builtins.int
    INPUT_SCHEMA_MAPPING_FIELD_NUMBER: builtins.int
    PUBLIC_NETWORK_ACCESS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def identity(self) -> global___IdentityInfo: ...
    location: builtins.str
    name: builtins.str
    auto_create_topic_with_first_subscription: builtins.bool
    auto_delete_topic_with_last_subscription: builtins.bool
    disable_local_auth: builtins.bool
    @property
    def inbound_ip_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___InboundIpRule]: ...
    input_schema: builtins.str
    @property
    def input_schema_mapping(self) -> global___InputSchemaMapping: ...
    public_network_access: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        identity: global___IdentityInfo | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        auto_create_topic_with_first_subscription: builtins.bool = ...,
        auto_delete_topic_with_last_subscription: builtins.bool = ...,
        disable_local_auth: builtins.bool = ...,
        inbound_ip_rules: collections.abc.Iterable[global___InboundIpRule] | None = ...,
        input_schema: builtins.str = ...,
        input_schema_mapping: global___InputSchemaMapping | None = ...,
        public_network_access: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identity", b"identity", "input_schema_mapping", b"input_schema_mapping", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auto_create_topic_with_first_subscription", b"auto_create_topic_with_first_subscription", "auto_delete_topic_with_last_subscription", b"auto_delete_topic_with_last_subscription", "disable_local_auth", b"disable_local_auth", "identity", b"identity", "inbound_ip_rules", b"inbound_ip_rules", "input_schema", b"input_schema", "input_schema_mapping", b"input_schema_mapping", "location", b"location", "name", b"name", "public_network_access", b"public_network_access", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___Domains = Domains

@typing_extensions.final
class InputSchemaMapping(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___InputSchemaMapping = InputSchemaMapping

@typing_extensions.final
class InboundIpRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTION_FIELD_NUMBER: builtins.int
    IP_MASK_FIELD_NUMBER: builtins.int
    action: builtins.str
    ip_mask: builtins.str
    def __init__(
        self,
        *,
        action: builtins.str = ...,
        ip_mask: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "ip_mask", b"ip_mask"]) -> None: ...

global___InboundIpRule = InboundIpRule

@typing_extensions.final
class IdentityInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class UserAssignedIdentitiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    PRINCIPAL_ID_FIELD_NUMBER: builtins.int
    TENANT_ID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    USER_ASSIGNED_IDENTITIES_FIELD_NUMBER: builtins.int
    principal_id: builtins.str
    tenant_id: builtins.str
    type: builtins.str
    @property
    def user_assigned_identities(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        principal_id: builtins.str = ...,
        tenant_id: builtins.str = ...,
        type: builtins.str = ...,
        user_assigned_identities: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["principal_id", b"principal_id", "tenant_id", b"tenant_id", "type", b"type", "user_assigned_identities", b"user_assigned_identities"]) -> None: ...

global___IdentityInfo = IdentityInfo



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_iotanalytics.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x61ws/aws_iotanalytics.proto\x12\x1coak9.tython.aws.iotanalytics\x1a\x13shared/shared.proto\"\x89\x01\n\x18\x43hannelCustomerManagedS3\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06\x62ucket\x18\x02 \x01(\t\x12\x10\n\x08role_arn\x18\x03 \x01(\t\x12\x12\n\nkey_prefix\x18\x04 \x01(\t\"R\n\x17\x43hannelServiceManagedS3\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xf8\x01\n\x15\x43hannelChannelStorage\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12S\n\x13\x63ustomer_managed_s3\x18\x02 \x01(\x0b\x32\x36.oak9.tython.aws.iotanalytics.ChannelCustomerManagedS3\x12Q\n\x12service_managed_s3\x18\x03 \x01(\x0b\x32\x35.oak9.tython.aws.iotanalytics.ChannelServiceManagedS3\"|\n\x16\x43hannelRetentionPeriod\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0enumber_of_days\x18\x02 \x01(\x05\x12\x11\n\tunlimited\x18\x03 \x01(\x08\"\xe2\x02\n\x07\x43hannel\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12L\n\x0f\x63hannel_storage\x18\x03 \x01(\x0b\x32\x33.oak9.tython.aws.iotanalytics.ChannelChannelStorage\x12N\n\x10retention_period\x18\x04 \x01(\x0b\x32\x34.oak9.tython.aws.iotanalytics.ChannelRetentionPeriod\x12=\n\x04tags\x18\x05 \x03(\x0b\x32/.oak9.tython.aws.iotanalytics.Channel.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf4\x01\n\x0cIoTAnalytics\x12\x36\n\x07\x63hannel\x18\x01 \x03(\x0b\x32%.oak9.tython.aws.iotanalytics.Channel\x12\x36\n\x07\x64\x61taset\x18\x02 \x03(\x0b\x32%.oak9.tython.aws.iotanalytics.Dataset\x12:\n\tdatastore\x18\x03 \x03(\x0b\x32\'.oak9.tython.aws.iotanalytics.Datastore\x12\x38\n\x08pipeline\x18\x04 \x03(\x0b\x32&.oak9.tython.aws.iotanalytics.Pipeline\"r\n!DatasetDatasetContentVersionValue\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0c\x64\x61taset_name\x18\x02 \x01(\t\"g\n\x19\x44\x61tasetOutputFileUriValue\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tfile_name\x18\x02 \x01(\t\"\xcd\x02\n\x0f\x44\x61tasetVariable\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x66\n\x1d\x64\x61taset_content_version_value\x18\x02 \x01(\x0b\x32?.oak9.tython.aws.iotanalytics.DatasetDatasetContentVersionValue\x12\x14\n\x0c\x64ouble_value\x18\x03 \x01(\x01\x12V\n\x15output_file_uri_value\x18\x04 \x01(\x0b\x32\x37.oak9.tython.aws.iotanalytics.DatasetOutputFileUriValue\x12\x15\n\rvariable_name\x18\x05 \x01(\t\x12\x14\n\x0cstring_value\x18\x06 \x01(\t\"\x88\x01\n\x1c\x44\x61tasetResourceConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11volume_size_in_gb\x18\x02 \x01(\x05\x12\x14\n\x0c\x63ompute_type\x18\x03 \x01(\t\"\x9a\x02\n\x16\x44\x61tasetContainerAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12@\n\tvariables\x18\x02 \x03(\x0b\x32-.oak9.tython.aws.iotanalytics.DatasetVariable\x12\x1a\n\x12\x65xecution_role_arn\x18\x03 \x01(\t\x12\r\n\x05image\x18\x04 \x01(\t\x12Z\n\x16resource_configuration\x18\x05 \x01(\x0b\x32:.oak9.tython.aws.iotanalytics.DatasetResourceConfiguration\"|\n\x10\x44\x61tasetDeltaTime\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0ftime_expression\x18\x02 \x01(\t\x12\x16\n\x0eoffset_seconds\x18\x03 \x01(\x05\"\x8c\x01\n\rDatasetFilter\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x42\n\ndelta_time\x18\x02 \x01(\x0b\x32..oak9.tython.aws.iotanalytics.DatasetDeltaTime\"\x9e\x01\n\x12\x44\x61tasetQueryAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12<\n\x07\x66ilters\x18\x02 \x03(\x0b\x32+.oak9.tython.aws.iotanalytics.DatasetFilter\x12\x11\n\tsql_query\x18\x03 \x01(\t\"\xf5\x01\n\rDatasetAction\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x61\x63tion_name\x18\x02 \x01(\t\x12N\n\x10\x63ontainer_action\x18\x03 \x01(\x0b\x32\x34.oak9.tython.aws.iotanalytics.DatasetContainerAction\x12\x46\n\x0cquery_action\x18\x04 \x01(\x0b\x32\x30.oak9.tython.aws.iotanalytics.DatasetQueryAction\"\x89\x01\n(DatasetIotEventsDestinationConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\ninput_name\x18\x02 \x01(\t\x12\x10\n\x08role_arn\x18\x03 \x01(\t\"~\n\x18\x44\x61tasetGlueConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\ntable_name\x18\x02 \x01(\t\x12\x15\n\rdatabase_name\x18\x03 \x01(\t\"\xdf\x01\n!DatasetS3DestinationConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12R\n\x12glue_configuration\x18\x02 \x01(\x0b\x32\x36.oak9.tython.aws.iotanalytics.DatasetGlueConfiguration\x12\x0e\n\x06\x62ucket\x18\x03 \x01(\t\x12\x0b\n\x03key\x18\x04 \x01(\t\x12\x10\n\x08role_arn\x18\x05 \x01(\t\"\xc4\x02\n,DatasetDatasetContentDeliveryRuleDestination\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12t\n$iot_events_destination_configuration\x18\x02 \x01(\x0b\x32\x46.oak9.tython.aws.iotanalytics.DatasetIotEventsDestinationConfiguration\x12\x65\n\x1cs3_destination_configuration\x18\x03 \x01(\x0b\x32?.oak9.tython.aws.iotanalytics.DatasetS3DestinationConfiguration\"\xd1\x01\n!DatasetDatasetContentDeliveryRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12_\n\x0b\x64\x65stination\x18\x02 \x01(\x0b\x32J.oak9.tython.aws.iotanalytics.DatasetDatasetContentDeliveryRuleDestination\x12\x12\n\nentry_name\x18\x03 \x01(\t\"g\n\x0f\x44\x61tasetSchedule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13schedule_expression\x18\x02 \x01(\t\"i\n\x18\x44\x61tasetTriggeringDataset\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0c\x64\x61taset_name\x18\x02 \x01(\t\"\xde\x01\n\x0e\x44\x61tasetTrigger\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12?\n\x08schedule\x18\x02 \x01(\x0b\x32-.oak9.tython.aws.iotanalytics.DatasetSchedule\x12R\n\x12triggering_dataset\x18\x03 \x01(\x0b\x32\x36.oak9.tython.aws.iotanalytics.DatasetTriggeringDataset\"\x82\x01\n\x1e\x44\x61tasetVersioningConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cmax_versions\x18\x02 \x01(\x05\x12\x11\n\tunlimited\x18\x03 \x01(\x08\"|\n\x16\x44\x61tasetRetentionPeriod\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0enumber_of_days\x18\x02 \x01(\x05\x12\x11\n\tunlimited\x18\x03 \x01(\x08\"\xd3\x04\n\x07\x44\x61taset\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12<\n\x07\x61\x63tions\x18\x02 \x03(\x0b\x32+.oak9.tython.aws.iotanalytics.DatasetAction\x12\x14\n\x0c\x64\x61taset_name\x18\x03 \x01(\t\x12_\n\x16\x63ontent_delivery_rules\x18\x04 \x03(\x0b\x32?.oak9.tython.aws.iotanalytics.DatasetDatasetContentDeliveryRule\x12>\n\x08triggers\x18\x05 \x03(\x0b\x32,.oak9.tython.aws.iotanalytics.DatasetTrigger\x12^\n\x18versioning_configuration\x18\x06 \x01(\x0b\x32<.oak9.tython.aws.iotanalytics.DatasetVersioningConfiguration\x12N\n\x10retention_period\x18\x07 \x01(\x0b\x32\x34.oak9.tython.aws.iotanalytics.DatasetRetentionPeriod\x12=\n\x04tags\x18\x08 \x03(\x0b\x32/.oak9.tython.aws.iotanalytics.Dataset.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8b\x01\n\x1a\x44\x61tastoreCustomerManagedS3\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06\x62ucket\x18\x02 \x01(\t\x12\x10\n\x08role_arn\x18\x03 \x01(\t\x12\x12\n\nkey_prefix\x18\x04 \x01(\t\"T\n\x19\x44\x61tastoreServiceManagedS3\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x80\x02\n\x19\x44\x61tastoreDatastoreStorage\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12U\n\x13\x63ustomer_managed_s3\x18\x02 \x01(\x0b\x32\x38.oak9.tython.aws.iotanalytics.DatastoreCustomerManagedS3\x12S\n\x12service_managed_s3\x18\x03 \x01(\x0b\x32\x37.oak9.tython.aws.iotanalytics.DatastoreServiceManagedS3\"~\n\x18\x44\x61tastoreRetentionPeriod\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0enumber_of_days\x18\x02 \x01(\x05\x12\x11\n\tunlimited\x18\x03 \x01(\x08\"\xf0\x02\n\tDatastore\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12R\n\x11\x64\x61tastore_storage\x18\x02 \x01(\x0b\x32\x37.oak9.tython.aws.iotanalytics.DatastoreDatastoreStorage\x12\x16\n\x0e\x64\x61tastore_name\x18\x03 \x01(\t\x12P\n\x10retention_period\x18\x04 \x01(\x0b\x32\x36.oak9.tython.aws.iotanalytics.DatastoreRetentionPeriod\x12?\n\x04tags\x18\x05 \x03(\x0b\x32\x31.oak9.tython.aws.iotanalytics.Datastore.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x83\x01\n\x18PipelineSelectAttributes\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04next\x18\x02 \x01(\t\x12\x12\n\nattributes\x18\x03 \x03(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\"r\n\x11PipelineDatastore\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x64\x61tastore_name\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"u\n\x0ePipelineFilter\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06\x66ilter\x18\x02 \x01(\t\x12\x0c\n\x04next\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\"\xf8\x01\n\x15PipelineAddAttributes\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04next\x18\x02 \x01(\t\x12W\n\nattributes\x18\x03 \x03(\x0b\x32\x43.oak9.tython.aws.iotanalytics.PipelineAddAttributes.AttributesEntry\x12\x0c\n\x04name\x18\x04 \x01(\t\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"|\n\x0fPipelineChannel\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0c\x63hannel_name\x18\x02 \x01(\t\x12\x0c\n\x04next\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\"\xaa\x01\n\x1aPipelineDeviceShadowEnrich\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tattribute\x18\x02 \x01(\t\x12\x0c\n\x04next\x18\x03 \x01(\t\x12\x12\n\nthing_name\x18\x04 \x01(\t\x12\x10\n\x08role_arn\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\"\x84\x01\n\x0cPipelineMath\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tattribute\x18\x02 \x01(\t\x12\x0c\n\x04next\x18\x03 \x01(\t\x12\x0c\n\x04math\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\"\x8e\x01\n\x0ePipelineLambda\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nbatch_size\x18\x02 \x01(\x05\x12\x0c\n\x04next\x18\x03 \x01(\t\x12\x13\n\x0blambda_name\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\"\xac\x01\n\x1cPipelineDeviceRegistryEnrich\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tattribute\x18\x02 \x01(\t\x12\x0c\n\x04next\x18\x03 \x01(\t\x12\x12\n\nthing_name\x18\x04 \x01(\t\x12\x10\n\x08role_arn\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\"\x83\x01\n\x18PipelineRemoveAttributes\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04next\x18\x02 \x01(\t\x12\x12\n\nattributes\x18\x03 \x03(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\"\xac\x06\n\x10PipelineActivity\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12Q\n\x11select_attributes\x18\x02 \x01(\x0b\x32\x36.oak9.tython.aws.iotanalytics.PipelineSelectAttributes\x12\x42\n\tdatastore\x18\x03 \x01(\x0b\x32/.oak9.tython.aws.iotanalytics.PipelineDatastore\x12<\n\x06\x66ilter\x18\x04 \x01(\x0b\x32,.oak9.tython.aws.iotanalytics.PipelineFilter\x12K\n\x0e\x61\x64\x64_attributes\x18\x05 \x01(\x0b\x32\x33.oak9.tython.aws.iotanalytics.PipelineAddAttributes\x12>\n\x07\x63hannel\x18\x06 \x01(\x0b\x32-.oak9.tython.aws.iotanalytics.PipelineChannel\x12V\n\x14\x64\x65vice_shadow_enrich\x18\x07 \x01(\x0b\x32\x38.oak9.tython.aws.iotanalytics.PipelineDeviceShadowEnrich\x12\x38\n\x04math\x18\x08 \x01(\x0b\x32*.oak9.tython.aws.iotanalytics.PipelineMath\x12<\n\x06lambda\x18\t \x01(\x0b\x32,.oak9.tython.aws.iotanalytics.PipelineLambda\x12Z\n\x16\x64\x65vice_registry_enrich\x18\n \x01(\x0b\x32:.oak9.tython.aws.iotanalytics.PipelineDeviceRegistryEnrich\x12Q\n\x11remove_attributes\x18\x0b \x01(\x0b\x32\x36.oak9.tython.aws.iotanalytics.PipelineRemoveAttributes\"\x94\x02\n\x08Pipeline\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rpipeline_name\x18\x02 \x01(\t\x12>\n\x04tags\x18\x03 \x03(\x0b\x32\x30.oak9.tython.aws.iotanalytics.Pipeline.TagsEntry\x12K\n\x13pipeline_activities\x18\x04 \x03(\x0b\x32..oak9.tython.aws.iotanalytics.PipelineActivity\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_iotanalytics_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CHANNEL_TAGSENTRY._options = None
  _CHANNEL_TAGSENTRY._serialized_options = b'8\001'
  _DATASET_TAGSENTRY._options = None
  _DATASET_TAGSENTRY._serialized_options = b'8\001'
  _DATASTORE_TAGSENTRY._options = None
  _DATASTORE_TAGSENTRY._serialized_options = b'8\001'
  _PIPELINEADDATTRIBUTES_ATTRIBUTESENTRY._options = None
  _PIPELINEADDATTRIBUTES_ATTRIBUTESENTRY._serialized_options = b'8\001'
  _PIPELINE_TAGSENTRY._options = None
  _PIPELINE_TAGSENTRY._serialized_options = b'8\001'
  _CHANNELCUSTOMERMANAGEDS3._serialized_start=82
  _CHANNELCUSTOMERMANAGEDS3._serialized_end=219
  _CHANNELSERVICEMANAGEDS3._serialized_start=221
  _CHANNELSERVICEMANAGEDS3._serialized_end=303
  _CHANNELCHANNELSTORAGE._serialized_start=306
  _CHANNELCHANNELSTORAGE._serialized_end=554
  _CHANNELRETENTIONPERIOD._serialized_start=556
  _CHANNELRETENTIONPERIOD._serialized_end=680
  _CHANNEL._serialized_start=683
  _CHANNEL._serialized_end=1037
  _CHANNEL_TAGSENTRY._serialized_start=994
  _CHANNEL_TAGSENTRY._serialized_end=1037
  _IOTANALYTICS._serialized_start=1040
  _IOTANALYTICS._serialized_end=1284
  _DATASETDATASETCONTENTVERSIONVALUE._serialized_start=1286
  _DATASETDATASETCONTENTVERSIONVALUE._serialized_end=1400
  _DATASETOUTPUTFILEURIVALUE._serialized_start=1402
  _DATASETOUTPUTFILEURIVALUE._serialized_end=1505
  _DATASETVARIABLE._serialized_start=1508
  _DATASETVARIABLE._serialized_end=1841
  _DATASETRESOURCECONFIGURATION._serialized_start=1844
  _DATASETRESOURCECONFIGURATION._serialized_end=1980
  _DATASETCONTAINERACTION._serialized_start=1983
  _DATASETCONTAINERACTION._serialized_end=2265
  _DATASETDELTATIME._serialized_start=2267
  _DATASETDELTATIME._serialized_end=2391
  _DATASETFILTER._serialized_start=2394
  _DATASETFILTER._serialized_end=2534
  _DATASETQUERYACTION._serialized_start=2537
  _DATASETQUERYACTION._serialized_end=2695
  _DATASETACTION._serialized_start=2698
  _DATASETACTION._serialized_end=2943
  _DATASETIOTEVENTSDESTINATIONCONFIGURATION._serialized_start=2946
  _DATASETIOTEVENTSDESTINATIONCONFIGURATION._serialized_end=3083
  _DATASETGLUECONFIGURATION._serialized_start=3085
  _DATASETGLUECONFIGURATION._serialized_end=3211
  _DATASETS3DESTINATIONCONFIGURATION._serialized_start=3214
  _DATASETS3DESTINATIONCONFIGURATION._serialized_end=3437
  _DATASETDATASETCONTENTDELIVERYRULEDESTINATION._serialized_start=3440
  _DATASETDATASETCONTENTDELIVERYRULEDESTINATION._serialized_end=3764
  _DATASETDATASETCONTENTDELIVERYRULE._serialized_start=3767
  _DATASETDATASETCONTENTDELIVERYRULE._serialized_end=3976
  _DATASETSCHEDULE._serialized_start=3978
  _DATASETSCHEDULE._serialized_end=4081
  _DATASETTRIGGERINGDATASET._serialized_start=4083
  _DATASETTRIGGERINGDATASET._serialized_end=4188
  _DATASETTRIGGER._serialized_start=4191
  _DATASETTRIGGER._serialized_end=4413
  _DATASETVERSIONINGCONFIGURATION._serialized_start=4416
  _DATASETVERSIONINGCONFIGURATION._serialized_end=4546
  _DATASETRETENTIONPERIOD._serialized_start=4548
  _DATASETRETENTIONPERIOD._serialized_end=4672
  _DATASET._serialized_start=4675
  _DATASET._serialized_end=5270
  _DATASET_TAGSENTRY._serialized_start=994
  _DATASET_TAGSENTRY._serialized_end=1037
  _DATASTORECUSTOMERMANAGEDS3._serialized_start=5273
  _DATASTORECUSTOMERMANAGEDS3._serialized_end=5412
  _DATASTORESERVICEMANAGEDS3._serialized_start=5414
  _DATASTORESERVICEMANAGEDS3._serialized_end=5498
  _DATASTOREDATASTORESTORAGE._serialized_start=5501
  _DATASTOREDATASTORESTORAGE._serialized_end=5757
  _DATASTORERETENTIONPERIOD._serialized_start=5759
  _DATASTORERETENTIONPERIOD._serialized_end=5885
  _DATASTORE._serialized_start=5888
  _DATASTORE._serialized_end=6256
  _DATASTORE_TAGSENTRY._serialized_start=994
  _DATASTORE_TAGSENTRY._serialized_end=1037
  _PIPELINESELECTATTRIBUTES._serialized_start=6259
  _PIPELINESELECTATTRIBUTES._serialized_end=6390
  _PIPELINEDATASTORE._serialized_start=6392
  _PIPELINEDATASTORE._serialized_end=6506
  _PIPELINEFILTER._serialized_start=6508
  _PIPELINEFILTER._serialized_end=6625
  _PIPELINEADDATTRIBUTES._serialized_start=6628
  _PIPELINEADDATTRIBUTES._serialized_end=6876
  _PIPELINEADDATTRIBUTES_ATTRIBUTESENTRY._serialized_start=6827
  _PIPELINEADDATTRIBUTES_ATTRIBUTESENTRY._serialized_end=6876
  _PIPELINECHANNEL._serialized_start=6878
  _PIPELINECHANNEL._serialized_end=7002
  _PIPELINEDEVICESHADOWENRICH._serialized_start=7005
  _PIPELINEDEVICESHADOWENRICH._serialized_end=7175
  _PIPELINEMATH._serialized_start=7178
  _PIPELINEMATH._serialized_end=7310
  _PIPELINELAMBDA._serialized_start=7313
  _PIPELINELAMBDA._serialized_end=7455
  _PIPELINEDEVICEREGISTRYENRICH._serialized_start=7458
  _PIPELINEDEVICEREGISTRYENRICH._serialized_end=7630
  _PIPELINEREMOVEATTRIBUTES._serialized_start=7633
  _PIPELINEREMOVEATTRIBUTES._serialized_end=7764
  _PIPELINEACTIVITY._serialized_start=7767
  _PIPELINEACTIVITY._serialized_end=8579
  _PIPELINE._serialized_start=8582
  _PIPELINE._serialized_end=8858
  _PIPELINE_TAGSENTRY._serialized_start=994
  _PIPELINE_TAGSENTRY._serialized_end=1037
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kubernetes/kubernetes_io.k8s.api.apiserverinternal.v1alpha1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAkubernetes/kubernetes_io.k8s.api.apiserverinternal.v1alpha1.proto\x12.oak9.tython.k8s.api.apiserverinternal.v1alpha1\x1a\x13shared/shared.proto\x1a@kubernetes/kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1.proto\"\x9c\x01\n\x14ServerStorageVersion\x12\x15\n\rapi_server_id\x18\x01 \x01(\t\x12\x1a\n\x12\x64\x65\x63odable_versions\x18\x02 \x03(\t\x12\x18\n\x10\x65ncoding_version\x18\x03 \x01(\t\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xe1\x02\n\x0eStorageVersion\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12P\n\x04spec\x18\x04 \x01(\x0b\x32\x42.oak9.tython.k8s.api.apiserverinternal.v1alpha1.StorageVersionSpec\x12T\n\x06status\x18\x05 \x01(\x0b\x32\x44.oak9.tython.k8s.api.apiserverinternal.v1alpha1.StorageVersionStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x81\x02\n\x17StorageVersionCondition\x12Q\n\x14last_transition_time\x18\x01 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x1b\n\x13observed_generation\x18\x03 \x01(\x05\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x0e\n\x06status\x18\x05 \x01(\t\x12\x0c\n\x04type\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x8a\x02\n\x12StorageVersionList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12M\n\x05items\x18\x02 \x03(\x0b\x32>.oak9.tython.k8s.api.apiserverinternal.v1alpha1.StorageVersion\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"M\n\x12StorageVersionSpec\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xad\x02\n\x14StorageVersionStatus\x12\x1f\n\x17\x63ommon_encoding_version\x18\x01 \x01(\t\x12[\n\nconditions\x18\x02 \x03(\x0b\x32G.oak9.tython.k8s.api.apiserverinternal.v1alpha1.StorageVersionCondition\x12^\n\x10storage_versions\x18\x03 \x03(\x0b\x32\x44.oak9.tython.k8s.api.apiserverinternal.v1alpha1.ServerStorageVersion\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'kubernetes.kubernetes_io.k8s.api.apiserverinternal.v1alpha1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SERVERSTORAGEVERSION._serialized_start=205
  _SERVERSTORAGEVERSION._serialized_end=361
  _STORAGEVERSION._serialized_start=364
  _STORAGEVERSION._serialized_end=717
  _STORAGEVERSIONCONDITION._serialized_start=720
  _STORAGEVERSIONCONDITION._serialized_end=977
  _STORAGEVERSIONLIST._serialized_start=980
  _STORAGEVERSIONLIST._serialized_end=1246
  _STORAGEVERSIONSPEC._serialized_start=1248
  _STORAGEVERSIONSPEC._serialized_end=1325
  _STORAGEVERSIONSTATUS._serialized_start=1328
  _STORAGEVERSIONSTATUS._serialized_end=1629
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_google_cloudfunctions_bundle.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.gcp import gcp_cloudfunctions_pb2 as gcp_dot_gcp__cloudfunctions__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*gcp/gcp_google_cloudfunctions_bundle.proto\x12,oak9.tython.gcp.google_cloudfunctions_bundle\x1a\x13shared/shared.proto\x1a\x1cgcp/gcp_cloudfunctions.proto\"\xb8\x03\n\x14GoogleCloudfunctions\x12W\n\x17\x63loudfunctions_function\x18\x01 \x01(\x0b\x32\x36.oak9.tython.gcp.cloudfunctions.CloudfunctionsFunction\x12m\n#cloudfunctions_function_iam_binding\x18\x02 \x03(\x0b\x32@.oak9.tython.gcp.cloudfunctions.CloudfunctionsFunctionIamBinding\x12k\n\"cloudfunctions_function_iam_member\x18\x03 \x03(\x0b\x32?.oak9.tython.gcp.cloudfunctions.CloudfunctionsFunctionIamMember\x12k\n\"cloudfunctions_function_iam_policy\x18\x04 \x03(\x0b\x32?.oak9.tython.gcp.cloudfunctions.CloudfunctionsFunctionIamPolicyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_google_cloudfunctions_bundle_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GOOGLECLOUDFUNCTIONS._serialized_start=144
  _GOOGLECLOUDFUNCTIONS._serialized_end=584
# @@protoc_insertion_point(module_scope)
